"""
    Delphix DCT API

    Delphix DCT API  # noqa: E501

    The version of the OpenAPI document: 3.27.0
    Contact: support@delphix.com
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401
import sys  # noqa: F401

from delphix.api.gateway.api_client import ApiClient, Endpoint as _Endpoint
from delphix.api.gateway.model_utils import (  # noqa: F401
    check_allowed_values,
    check_validations,
    date,
    datetime,
    file_type,
    none_type,
    validate_and_convert_types
)
from delphix.api.gateway.model.create_hyperscale_connector_response import CreateHyperscaleConnectorResponse
from delphix.api.gateway.model.create_hyperscale_mount_point_response import CreateHyperscaleMountPointResponse
from delphix.api.gateway.model.delete_hyperscale_connector_response import DeleteHyperscaleConnectorResponse
from delphix.api.gateway.model.delete_hyperscale_mount_point_response import DeleteHyperscaleMountPointResponse
from delphix.api.gateway.model.delete_tag import DeleteTag
from delphix.api.gateway.model.hyperscale_connector import HyperscaleConnector
from delphix.api.gateway.model.hyperscale_connector_create_parameters import HyperscaleConnectorCreateParameters
from delphix.api.gateway.model.hyperscale_connector_update_parameters import HyperscaleConnectorUpdateParameters
from delphix.api.gateway.model.hyperscale_dataset import HyperscaleDataset
from delphix.api.gateway.model.hyperscale_dataset_table_or_file import HyperscaleDatasetTableOrFile
from delphix.api.gateway.model.hyperscale_dataset_table_or_file_update_parameters import HyperscaleDatasetTableOrFileUpdateParameters
from delphix.api.gateway.model.hyperscale_dataset_update_parameters import HyperscaleDatasetUpdateParameters
from delphix.api.gateway.model.hyperscale_mount_point import HyperscaleMountPoint
from delphix.api.gateway.model.hyperscale_mount_point_update_parameters import HyperscaleMountPointUpdateParameters
from delphix.api.gateway.model.list_hyperscale_connectors_response import ListHyperscaleConnectorsResponse
from delphix.api.gateway.model.list_hyperscale_dataset_tables_or_files_response import ListHyperscaleDatasetTablesOrFilesResponse
from delphix.api.gateway.model.list_hyperscale_datasets_response import ListHyperscaleDatasetsResponse
from delphix.api.gateway.model.list_hyperscale_mount_points_response import ListHyperscaleMountPointsResponse
from delphix.api.gateway.model.search_body import SearchBody
from delphix.api.gateway.model.search_hyperscale_connectors_response import SearchHyperscaleConnectorsResponse
from delphix.api.gateway.model.search_hyperscale_dataset_tables_or_files_response import SearchHyperscaleDatasetTablesOrFilesResponse
from delphix.api.gateway.model.search_hyperscale_datasets_response import SearchHyperscaleDatasetsResponse
from delphix.api.gateway.model.search_hyperscale_mount_points_response import SearchHyperscaleMountPointsResponse
from delphix.api.gateway.model.tags_request import TagsRequest
from delphix.api.gateway.model.tags_response import TagsResponse
from delphix.api.gateway.model.update_hyperscale_connector_response import UpdateHyperscaleConnectorResponse
from delphix.api.gateway.model.update_hyperscale_dataset_response import UpdateHyperscaleDatasetResponse
from delphix.api.gateway.model.update_hyperscale_dataset_table_or_file_response import UpdateHyperscaleDatasetTableOrFileResponse
from delphix.api.gateway.model.update_hyperscale_mount_point_response import UpdateHyperscaleMountPointResponse


class HyperscaleObjectsApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

        def __create_hyperscale_connector(
            self,
            hyperscale_connector_create_parameters,
            **kwargs
        ):
            """Create a Hyperscale Connector.  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.create_hyperscale_connector(hyperscale_connector_create_parameters, async_req=True)
            >>> result = thread.get()

            Args:
                hyperscale_connector_create_parameters (HyperscaleConnectorCreateParameters):

            Keyword Args:
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                CreateHyperscaleConnectorResponse
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['hyperscale_connector_create_parameters'] = \
                hyperscale_connector_create_parameters
            return self.call_with_http_info(**kwargs)

        self.create_hyperscale_connector = _Endpoint(
            settings={
                'response_type': (CreateHyperscaleConnectorResponse,),
                'auth': [
                    'ApiKeyAuth'
                ],
                'endpoint_path': '/hyperscale-connectors',
                'operation_id': 'create_hyperscale_connector',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'hyperscale_connector_create_parameters',
                ],
                'required': [
                    'hyperscale_connector_create_parameters',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'hyperscale_connector_create_parameters':
                        (HyperscaleConnectorCreateParameters,),
                },
                'attribute_map': {
                },
                'location_map': {
                    'hyperscale_connector_create_parameters': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client,
            callable=__create_hyperscale_connector
        )

        def __create_hyperscale_connector_tags(
            self,
            hyperscale_connector_id,
            tags_request,
            **kwargs
        ):
            """Create tags for a Hyperscale Connector.  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.create_hyperscale_connector_tags(hyperscale_connector_id, tags_request, async_req=True)
            >>> result = thread.get()

            Args:
                hyperscale_connector_id (str): The ID of the Hyperscale Connector.
                tags_request (TagsRequest): Tag information for a Hyperscale Connector.

            Keyword Args:
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                TagsResponse
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['hyperscale_connector_id'] = \
                hyperscale_connector_id
            kwargs['tags_request'] = \
                tags_request
            return self.call_with_http_info(**kwargs)

        self.create_hyperscale_connector_tags = _Endpoint(
            settings={
                'response_type': (TagsResponse,),
                'auth': [
                    'ApiKeyAuth'
                ],
                'endpoint_path': '/hyperscale-connectors/{hyperscaleConnectorId}/tags',
                'operation_id': 'create_hyperscale_connector_tags',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'hyperscale_connector_id',
                    'tags_request',
                ],
                'required': [
                    'hyperscale_connector_id',
                    'tags_request',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                    'hyperscale_connector_id',
                ]
            },
            root_map={
                'validations': {
                    ('hyperscale_connector_id',): {

                        'min_length': 1,
                    },
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'hyperscale_connector_id':
                        (str,),
                    'tags_request':
                        (TagsRequest,),
                },
                'attribute_map': {
                    'hyperscale_connector_id': 'hyperscaleConnectorId',
                },
                'location_map': {
                    'hyperscale_connector_id': 'path',
                    'tags_request': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client,
            callable=__create_hyperscale_connector_tags
        )

        def __create_hyperscale_dataset_tags(
            self,
            hyperscale_dataset_id,
            tags_request,
            **kwargs
        ):
            """Create tags for a Hyperscale Dataset.  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.create_hyperscale_dataset_tags(hyperscale_dataset_id, tags_request, async_req=True)
            >>> result = thread.get()

            Args:
                hyperscale_dataset_id (str): The ID of the Hyperscale Dataset.
                tags_request (TagsRequest): Tag information for a Hyperscale Dataset.

            Keyword Args:
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                TagsResponse
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['hyperscale_dataset_id'] = \
                hyperscale_dataset_id
            kwargs['tags_request'] = \
                tags_request
            return self.call_with_http_info(**kwargs)

        self.create_hyperscale_dataset_tags = _Endpoint(
            settings={
                'response_type': (TagsResponse,),
                'auth': [
                    'ApiKeyAuth'
                ],
                'endpoint_path': '/hyperscale-datasets/{hyperscaleDatasetId}/tags',
                'operation_id': 'create_hyperscale_dataset_tags',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'hyperscale_dataset_id',
                    'tags_request',
                ],
                'required': [
                    'hyperscale_dataset_id',
                    'tags_request',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                    'hyperscale_dataset_id',
                ]
            },
            root_map={
                'validations': {
                    ('hyperscale_dataset_id',): {

                        'min_length': 1,
                    },
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'hyperscale_dataset_id':
                        (str,),
                    'tags_request':
                        (TagsRequest,),
                },
                'attribute_map': {
                    'hyperscale_dataset_id': 'hyperscaleDatasetId',
                },
                'location_map': {
                    'hyperscale_dataset_id': 'path',
                    'tags_request': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client,
            callable=__create_hyperscale_dataset_tags
        )

        def __create_hyperscale_mount_point(
            self,
            hyperscale_mount_point,
            **kwargs
        ):
            """Create a Hyperscale Mount Point  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.create_hyperscale_mount_point(hyperscale_mount_point, async_req=True)
            >>> result = thread.get()

            Args:
                hyperscale_mount_point (HyperscaleMountPoint): Request to create a Hyperscale Mount Point.

            Keyword Args:
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                CreateHyperscaleMountPointResponse
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['hyperscale_mount_point'] = \
                hyperscale_mount_point
            return self.call_with_http_info(**kwargs)

        self.create_hyperscale_mount_point = _Endpoint(
            settings={
                'response_type': (CreateHyperscaleMountPointResponse,),
                'auth': [
                    'ApiKeyAuth'
                ],
                'endpoint_path': '/hyperscale-mount-points',
                'operation_id': 'create_hyperscale_mount_point',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'hyperscale_mount_point',
                ],
                'required': [
                    'hyperscale_mount_point',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'hyperscale_mount_point':
                        (HyperscaleMountPoint,),
                },
                'attribute_map': {
                },
                'location_map': {
                    'hyperscale_mount_point': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client,
            callable=__create_hyperscale_mount_point
        )

        def __delete_hyperscale_connector(
            self,
            hyperscale_connector_id,
            **kwargs
        ):
            """Delete a Hyperscale Connector.  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.delete_hyperscale_connector(hyperscale_connector_id, async_req=True)
            >>> result = thread.get()

            Args:
                hyperscale_connector_id (str): The ID of the Hyperscale Connector.

            Keyword Args:
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                DeleteHyperscaleConnectorResponse
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['hyperscale_connector_id'] = \
                hyperscale_connector_id
            return self.call_with_http_info(**kwargs)

        self.delete_hyperscale_connector = _Endpoint(
            settings={
                'response_type': (DeleteHyperscaleConnectorResponse,),
                'auth': [
                    'ApiKeyAuth'
                ],
                'endpoint_path': '/hyperscale-connectors/{hyperscaleConnectorId}',
                'operation_id': 'delete_hyperscale_connector',
                'http_method': 'DELETE',
                'servers': None,
            },
            params_map={
                'all': [
                    'hyperscale_connector_id',
                ],
                'required': [
                    'hyperscale_connector_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                    'hyperscale_connector_id',
                ]
            },
            root_map={
                'validations': {
                    ('hyperscale_connector_id',): {

                        'min_length': 1,
                    },
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'hyperscale_connector_id':
                        (str,),
                },
                'attribute_map': {
                    'hyperscale_connector_id': 'hyperscaleConnectorId',
                },
                'location_map': {
                    'hyperscale_connector_id': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client,
            callable=__delete_hyperscale_connector
        )

        def __delete_hyperscale_connector_tags(
            self,
            hyperscale_connector_id,
            **kwargs
        ):
            """Delete tags for a Hyperscale Connector.  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.delete_hyperscale_connector_tags(hyperscale_connector_id, async_req=True)
            >>> result = thread.get()

            Args:
                hyperscale_connector_id (str): The ID of the Hyperscale Connector.

            Keyword Args:
                delete_tag (DeleteTag): The parameters to delete tags. [optional]
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                None
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['hyperscale_connector_id'] = \
                hyperscale_connector_id
            return self.call_with_http_info(**kwargs)

        self.delete_hyperscale_connector_tags = _Endpoint(
            settings={
                'response_type': None,
                'auth': [
                    'ApiKeyAuth'
                ],
                'endpoint_path': '/hyperscale-connectors/{hyperscaleConnectorId}/tags/delete',
                'operation_id': 'delete_hyperscale_connector_tags',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'hyperscale_connector_id',
                    'delete_tag',
                ],
                'required': [
                    'hyperscale_connector_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                    'hyperscale_connector_id',
                ]
            },
            root_map={
                'validations': {
                    ('hyperscale_connector_id',): {

                        'min_length': 1,
                    },
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'hyperscale_connector_id':
                        (str,),
                    'delete_tag':
                        (DeleteTag,),
                },
                'attribute_map': {
                    'hyperscale_connector_id': 'hyperscaleConnectorId',
                },
                'location_map': {
                    'hyperscale_connector_id': 'path',
                    'delete_tag': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client,
            callable=__delete_hyperscale_connector_tags
        )

        def __delete_hyperscale_dataset_tags(
            self,
            hyperscale_dataset_id,
            **kwargs
        ):
            """Delete tags for a Hyperscale Dataset.  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.delete_hyperscale_dataset_tags(hyperscale_dataset_id, async_req=True)
            >>> result = thread.get()

            Args:
                hyperscale_dataset_id (str): The ID of the Hyperscale Dataset.

            Keyword Args:
                delete_tag (DeleteTag): The parameters to delete tags. [optional]
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                None
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['hyperscale_dataset_id'] = \
                hyperscale_dataset_id
            return self.call_with_http_info(**kwargs)

        self.delete_hyperscale_dataset_tags = _Endpoint(
            settings={
                'response_type': None,
                'auth': [
                    'ApiKeyAuth'
                ],
                'endpoint_path': '/hyperscale-datasets/{hyperscaleDatasetId}/tags/delete',
                'operation_id': 'delete_hyperscale_dataset_tags',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'hyperscale_dataset_id',
                    'delete_tag',
                ],
                'required': [
                    'hyperscale_dataset_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                    'hyperscale_dataset_id',
                ]
            },
            root_map={
                'validations': {
                    ('hyperscale_dataset_id',): {

                        'min_length': 1,
                    },
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'hyperscale_dataset_id':
                        (str,),
                    'delete_tag':
                        (DeleteTag,),
                },
                'attribute_map': {
                    'hyperscale_dataset_id': 'hyperscaleDatasetId',
                },
                'location_map': {
                    'hyperscale_dataset_id': 'path',
                    'delete_tag': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client,
            callable=__delete_hyperscale_dataset_tags
        )

        def __delete_hyperscale_mount_point(
            self,
            hyperscale_mount_point_id,
            **kwargs
        ):
            """Delete a Hyperscale Mount Point.  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.delete_hyperscale_mount_point(hyperscale_mount_point_id, async_req=True)
            >>> result = thread.get()

            Args:
                hyperscale_mount_point_id (str): The ID of the Hyperscale Mount Point.

            Keyword Args:
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                DeleteHyperscaleMountPointResponse
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['hyperscale_mount_point_id'] = \
                hyperscale_mount_point_id
            return self.call_with_http_info(**kwargs)

        self.delete_hyperscale_mount_point = _Endpoint(
            settings={
                'response_type': (DeleteHyperscaleMountPointResponse,),
                'auth': [
                    'ApiKeyAuth'
                ],
                'endpoint_path': '/hyperscale-mount-points/{hyperscaleMountPointId}',
                'operation_id': 'delete_hyperscale_mount_point',
                'http_method': 'DELETE',
                'servers': None,
            },
            params_map={
                'all': [
                    'hyperscale_mount_point_id',
                ],
                'required': [
                    'hyperscale_mount_point_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                    'hyperscale_mount_point_id',
                ]
            },
            root_map={
                'validations': {
                    ('hyperscale_mount_point_id',): {

                        'min_length': 1,
                    },
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'hyperscale_mount_point_id':
                        (str,),
                },
                'attribute_map': {
                    'hyperscale_mount_point_id': 'hyperscaleMountPointId',
                },
                'location_map': {
                    'hyperscale_mount_point_id': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client,
            callable=__delete_hyperscale_mount_point
        )

        def __get_hyperscale_connector_by_id(
            self,
            hyperscale_connector_id,
            **kwargs
        ):
            """Get a Hyperscale Connector.  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.get_hyperscale_connector_by_id(hyperscale_connector_id, async_req=True)
            >>> result = thread.get()

            Args:
                hyperscale_connector_id (str): The ID of the Hyperscale Connector.

            Keyword Args:
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                HyperscaleConnector
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['hyperscale_connector_id'] = \
                hyperscale_connector_id
            return self.call_with_http_info(**kwargs)

        self.get_hyperscale_connector_by_id = _Endpoint(
            settings={
                'response_type': (HyperscaleConnector,),
                'auth': [
                    'ApiKeyAuth'
                ],
                'endpoint_path': '/hyperscale-connectors/{hyperscaleConnectorId}',
                'operation_id': 'get_hyperscale_connector_by_id',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'hyperscale_connector_id',
                ],
                'required': [
                    'hyperscale_connector_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                    'hyperscale_connector_id',
                ]
            },
            root_map={
                'validations': {
                    ('hyperscale_connector_id',): {

                        'min_length': 1,
                    },
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'hyperscale_connector_id':
                        (str,),
                },
                'attribute_map': {
                    'hyperscale_connector_id': 'hyperscaleConnectorId',
                },
                'location_map': {
                    'hyperscale_connector_id': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client,
            callable=__get_hyperscale_connector_by_id
        )

        def __get_hyperscale_connector_tags(
            self,
            hyperscale_connector_id,
            **kwargs
        ):
            """Get tags for a Hyperscale Connector.  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.get_hyperscale_connector_tags(hyperscale_connector_id, async_req=True)
            >>> result = thread.get()

            Args:
                hyperscale_connector_id (str): The ID of the Hyperscale Connector.

            Keyword Args:
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                TagsResponse
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['hyperscale_connector_id'] = \
                hyperscale_connector_id
            return self.call_with_http_info(**kwargs)

        self.get_hyperscale_connector_tags = _Endpoint(
            settings={
                'response_type': (TagsResponse,),
                'auth': [
                    'ApiKeyAuth'
                ],
                'endpoint_path': '/hyperscale-connectors/{hyperscaleConnectorId}/tags',
                'operation_id': 'get_hyperscale_connector_tags',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'hyperscale_connector_id',
                ],
                'required': [
                    'hyperscale_connector_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                    'hyperscale_connector_id',
                ]
            },
            root_map={
                'validations': {
                    ('hyperscale_connector_id',): {

                        'min_length': 1,
                    },
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'hyperscale_connector_id':
                        (str,),
                },
                'attribute_map': {
                    'hyperscale_connector_id': 'hyperscaleConnectorId',
                },
                'location_map': {
                    'hyperscale_connector_id': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client,
            callable=__get_hyperscale_connector_tags
        )

        def __get_hyperscale_connectors(
            self,
            **kwargs
        ):
            """Returns a list of Hyperscale Connectors.  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.get_hyperscale_connectors(async_req=True)
            >>> result = thread.get()


            Keyword Args:
                limit (int): Maximum number of objects to return per query. The value must be between 1 and 1000. Default is 100.. [optional] if omitted the server will use the default value of 100
                cursor (str): Cursor to fetch the next or previous page of results. The value of this property must be extracted from the 'prev_cursor' or 'next_cursor' property of a PaginatedResponseMetadata which is contained in the response of list and search API endpoints.. [optional]
                sort (str, none_type): The field to sort results by. A property name with a prepended '-' signifies descending order.. [optional]
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                ListHyperscaleConnectorsResponse
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            return self.call_with_http_info(**kwargs)

        self.get_hyperscale_connectors = _Endpoint(
            settings={
                'response_type': (ListHyperscaleConnectorsResponse,),
                'auth': [
                    'ApiKeyAuth'
                ],
                'endpoint_path': '/hyperscale-connectors',
                'operation_id': 'get_hyperscale_connectors',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'limit',
                    'cursor',
                    'sort',
                ],
                'required': [],
                'nullable': [
                    'sort',
                ],
                'enum': [
                    'sort',
                ],
                'validation': [
                    'limit',
                    'cursor',
                ]
            },
            root_map={
                'validations': {
                    ('limit',): {

                        'inclusive_maximum': 1000,
                        'inclusive_minimum': 1,
                    },
                    ('cursor',): {
                        'max_length': 4096,
                        'min_length': 1,
                    },
                },
                'allowed_values': {
                    ('sort',): {
                        'None': None,
                        "ID": "id",
                        "-ID": "-id",
                        "NAME": "name",
                        "-NAME": "-name",
                        "HYPERSCALE_INSTANCE_ID": "hyperscale_instance_id",
                        "-HYPERSCALE_INSTANCE_ID": "-hyperscale_instance_id",
                        "DATA_TYPE": "data_type",
                        "-DATA_TYPE": "-data_type",
                        "SOURCE_USERNAME": "source_username",
                        "-SOURCE_USERNAME": "-source_username",
                        "SOURCE_JDBC_URL": "source_jdbc_url",
                        "-SOURCE_JDBC_URL": "-source_jdbc_url",
                        "SOURCE_MONGO_URL": "source_mongo_url",
                        "-SOURCE_MONGO_URL": "-source_mongo_url",
                        "TARGET_USERNAME": "target_username",
                        "-TARGET_USERNAME": "-target_username",
                        "TARGET_JDBC_URL": "target_jdbc_url",
                        "-TARGET_JDBC_URL": "-target_jdbc_url",
                        "TARGET_MONGO_URL": "target_mongo_url",
                        "-TARGET_MONGO_URL": "-target_mongo_url"
                    },
                },
                'openapi_types': {
                    'limit':
                        (int,),
                    'cursor':
                        (str,),
                    'sort':
                        (str, none_type,),
                },
                'attribute_map': {
                    'limit': 'limit',
                    'cursor': 'cursor',
                    'sort': 'sort',
                },
                'location_map': {
                    'limit': 'query',
                    'cursor': 'query',
                    'sort': 'query',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client,
            callable=__get_hyperscale_connectors
        )

        def __get_hyperscale_dataset_by_id(
            self,
            hyperscale_dataset_id,
            **kwargs
        ):
            """Get a Hyperscale Dataset.  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.get_hyperscale_dataset_by_id(hyperscale_dataset_id, async_req=True)
            >>> result = thread.get()

            Args:
                hyperscale_dataset_id (str): The ID of the Hyperscale Dataset.

            Keyword Args:
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                HyperscaleDataset
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['hyperscale_dataset_id'] = \
                hyperscale_dataset_id
            return self.call_with_http_info(**kwargs)

        self.get_hyperscale_dataset_by_id = _Endpoint(
            settings={
                'response_type': (HyperscaleDataset,),
                'auth': [
                    'ApiKeyAuth'
                ],
                'endpoint_path': '/hyperscale-datasets/{hyperscaleDatasetId}',
                'operation_id': 'get_hyperscale_dataset_by_id',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'hyperscale_dataset_id',
                ],
                'required': [
                    'hyperscale_dataset_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                    'hyperscale_dataset_id',
                ]
            },
            root_map={
                'validations': {
                    ('hyperscale_dataset_id',): {

                        'min_length': 1,
                    },
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'hyperscale_dataset_id':
                        (str,),
                },
                'attribute_map': {
                    'hyperscale_dataset_id': 'hyperscaleDatasetId',
                },
                'location_map': {
                    'hyperscale_dataset_id': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client,
            callable=__get_hyperscale_dataset_by_id
        )

        def __get_hyperscale_dataset_table_or_file_by_id(
            self,
            hyperscale_dataset_id,
            hyperscale_dataset_table_or_file_id,
            **kwargs
        ):
            """Get a Hyperscale Dataset table or file by ID.  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.get_hyperscale_dataset_table_or_file_by_id(hyperscale_dataset_id, hyperscale_dataset_table_or_file_id, async_req=True)
            >>> result = thread.get()

            Args:
                hyperscale_dataset_id (str): The ID of the Hyperscale Dataset.
                hyperscale_dataset_table_or_file_id (str): The ID of the Hyperscale Dataset table or file.

            Keyword Args:
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                HyperscaleDatasetTableOrFile
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['hyperscale_dataset_id'] = \
                hyperscale_dataset_id
            kwargs['hyperscale_dataset_table_or_file_id'] = \
                hyperscale_dataset_table_or_file_id
            return self.call_with_http_info(**kwargs)

        self.get_hyperscale_dataset_table_or_file_by_id = _Endpoint(
            settings={
                'response_type': (HyperscaleDatasetTableOrFile,),
                'auth': [
                    'ApiKeyAuth'
                ],
                'endpoint_path': '/hyperscale-datasets/{hyperscaleDatasetId}/tables-or-files/{hyperscaleDatasetTableOrFileId}',
                'operation_id': 'get_hyperscale_dataset_table_or_file_by_id',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'hyperscale_dataset_id',
                    'hyperscale_dataset_table_or_file_id',
                ],
                'required': [
                    'hyperscale_dataset_id',
                    'hyperscale_dataset_table_or_file_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                    'hyperscale_dataset_id',
                    'hyperscale_dataset_table_or_file_id',
                ]
            },
            root_map={
                'validations': {
                    ('hyperscale_dataset_id',): {

                        'min_length': 1,
                    },
                    ('hyperscale_dataset_table_or_file_id',): {

                        'min_length': 1,
                    },
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'hyperscale_dataset_id':
                        (str,),
                    'hyperscale_dataset_table_or_file_id':
                        (str,),
                },
                'attribute_map': {
                    'hyperscale_dataset_id': 'hyperscaleDatasetId',
                    'hyperscale_dataset_table_or_file_id': 'hyperscaleDatasetTableOrFileId',
                },
                'location_map': {
                    'hyperscale_dataset_id': 'path',
                    'hyperscale_dataset_table_or_file_id': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client,
            callable=__get_hyperscale_dataset_table_or_file_by_id
        )

        def __get_hyperscale_dataset_tables_or_files(
            self,
            hyperscale_dataset_id,
            **kwargs
        ):
            """Get the tables or files of a hyperscale dataset  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.get_hyperscale_dataset_tables_or_files(hyperscale_dataset_id, async_req=True)
            >>> result = thread.get()

            Args:
                hyperscale_dataset_id (str): The ID of the Hyperscale Dataset.

            Keyword Args:
                limit (int): Maximum number of objects to return per query. The value must be between 1 and 1000. Default is 100.. [optional] if omitted the server will use the default value of 100
                cursor (str): Cursor to fetch the next or previous page of results. The value of this property must be extracted from the 'prev_cursor' or 'next_cursor' property of a PaginatedResponseMetadata which is contained in the response of list and search API endpoints.. [optional]
                sort (str, none_type): The field to sort results by. A property name with a prepended '-' signifies descending order.. [optional]
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                ListHyperscaleDatasetTablesOrFilesResponse
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['hyperscale_dataset_id'] = \
                hyperscale_dataset_id
            return self.call_with_http_info(**kwargs)

        self.get_hyperscale_dataset_tables_or_files = _Endpoint(
            settings={
                'response_type': (ListHyperscaleDatasetTablesOrFilesResponse,),
                'auth': [
                    'ApiKeyAuth'
                ],
                'endpoint_path': '/hyperscale-datasets/{hyperscaleDatasetId}/tables-or-files',
                'operation_id': 'get_hyperscale_dataset_tables_or_files',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'hyperscale_dataset_id',
                    'limit',
                    'cursor',
                    'sort',
                ],
                'required': [
                    'hyperscale_dataset_id',
                ],
                'nullable': [
                    'sort',
                ],
                'enum': [
                    'sort',
                ],
                'validation': [
                    'hyperscale_dataset_id',
                    'limit',
                    'cursor',
                ]
            },
            root_map={
                'validations': {
                    ('hyperscale_dataset_id',): {

                        'min_length': 1,
                    },
                    ('limit',): {

                        'inclusive_maximum': 1000,
                        'inclusive_minimum': 1,
                    },
                    ('cursor',): {
                        'max_length': 4096,
                        'min_length': 1,
                    },
                },
                'allowed_values': {
                    ('sort',): {
                        'None': None,
                        "ID": "id",
                        "-ID": "-id",
                        "SCHEMA_NAME": "schema_name",
                        "-SCHEMA_NAME": "-schema_name",
                        "TABLE_NAME": "table_name",
                        "-TABLE_NAME": "-table_name",
                        "DATABASE_NAME": "database_name",
                        "-DATABASE_NAME": "-database_name",
                        "COLLECTION_NAME": "collection_name",
                        "-COLLECTION_NAME": "-collection_name",
                        "FILTER_KEY": "filter_key",
                        "-FILTER_KEY": "-filter_key",
                        "COLUMN_ARRAY_ROWS": "column_array_rows",
                        "-COLUMN_ARRAY_ROWS": "-column_array_rows",
                        "UNLOAD_SPLIT": "unload_split",
                        "-UNLOAD_SPLIT": "-unload_split",
                        "STREAM_SIZE": "stream_size",
                        "-STREAM_SIZE": "-stream_size"
                    },
                },
                'openapi_types': {
                    'hyperscale_dataset_id':
                        (str,),
                    'limit':
                        (int,),
                    'cursor':
                        (str,),
                    'sort':
                        (str, none_type,),
                },
                'attribute_map': {
                    'hyperscale_dataset_id': 'hyperscaleDatasetId',
                    'limit': 'limit',
                    'cursor': 'cursor',
                    'sort': 'sort',
                },
                'location_map': {
                    'hyperscale_dataset_id': 'path',
                    'limit': 'query',
                    'cursor': 'query',
                    'sort': 'query',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client,
            callable=__get_hyperscale_dataset_tables_or_files
        )

        def __get_hyperscale_dataset_tags(
            self,
            hyperscale_dataset_id,
            **kwargs
        ):
            """Get tags for a Hyperscale Dataset.  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.get_hyperscale_dataset_tags(hyperscale_dataset_id, async_req=True)
            >>> result = thread.get()

            Args:
                hyperscale_dataset_id (str): The ID of the Hyperscale Dataset.

            Keyword Args:
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                TagsResponse
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['hyperscale_dataset_id'] = \
                hyperscale_dataset_id
            return self.call_with_http_info(**kwargs)

        self.get_hyperscale_dataset_tags = _Endpoint(
            settings={
                'response_type': (TagsResponse,),
                'auth': [
                    'ApiKeyAuth'
                ],
                'endpoint_path': '/hyperscale-datasets/{hyperscaleDatasetId}/tags',
                'operation_id': 'get_hyperscale_dataset_tags',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'hyperscale_dataset_id',
                ],
                'required': [
                    'hyperscale_dataset_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                    'hyperscale_dataset_id',
                ]
            },
            root_map={
                'validations': {
                    ('hyperscale_dataset_id',): {

                        'min_length': 1,
                    },
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'hyperscale_dataset_id':
                        (str,),
                },
                'attribute_map': {
                    'hyperscale_dataset_id': 'hyperscaleDatasetId',
                },
                'location_map': {
                    'hyperscale_dataset_id': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client,
            callable=__get_hyperscale_dataset_tags
        )

        def __get_hyperscale_datasets(
            self,
            **kwargs
        ):
            """Returns a list of Hyperscale Datasets.  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.get_hyperscale_datasets(async_req=True)
            >>> result = thread.get()


            Keyword Args:
                limit (int): Maximum number of objects to return per query. The value must be between 1 and 1000. Default is 100.. [optional] if omitted the server will use the default value of 100
                cursor (str): Cursor to fetch the next or previous page of results. The value of this property must be extracted from the 'prev_cursor' or 'next_cursor' property of a PaginatedResponseMetadata which is contained in the response of list and search API endpoints.. [optional]
                sort (str, none_type): The field to sort results by. A property name with a prepended '-' signifies descending order.. [optional]
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                ListHyperscaleDatasetsResponse
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            return self.call_with_http_info(**kwargs)

        self.get_hyperscale_datasets = _Endpoint(
            settings={
                'response_type': (ListHyperscaleDatasetsResponse,),
                'auth': [
                    'ApiKeyAuth'
                ],
                'endpoint_path': '/hyperscale-datasets',
                'operation_id': 'get_hyperscale_datasets',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'limit',
                    'cursor',
                    'sort',
                ],
                'required': [],
                'nullable': [
                    'sort',
                ],
                'enum': [
                    'sort',
                ],
                'validation': [
                    'limit',
                    'cursor',
                ]
            },
            root_map={
                'validations': {
                    ('limit',): {

                        'inclusive_maximum': 1000,
                        'inclusive_minimum': 1,
                    },
                    ('cursor',): {
                        'max_length': 4096,
                        'min_length': 1,
                    },
                },
                'allowed_values': {
                    ('sort',): {
                        'None': None,
                        "ID": "id",
                        "-ID": "-id",
                        "HYPERSCALE_INSTANCE_ID": "hyperscale_instance_id",
                        "-HYPERSCALE_INSTANCE_ID": "-hyperscale_instance_id",
                        "DATA_TYPE": "data_type",
                        "-DATA_TYPE": "-data_type",
                        "CONNECTOR_ID": "connector_id",
                        "-CONNECTOR_ID": "-connector_id",
                        "MOUNT_POINT_ID": "mount_point_id",
                        "-MOUNT_POINT_ID": "-mount_point_id"
                    },
                },
                'openapi_types': {
                    'limit':
                        (int,),
                    'cursor':
                        (str,),
                    'sort':
                        (str, none_type,),
                },
                'attribute_map': {
                    'limit': 'limit',
                    'cursor': 'cursor',
                    'sort': 'sort',
                },
                'location_map': {
                    'limit': 'query',
                    'cursor': 'query',
                    'sort': 'query',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client,
            callable=__get_hyperscale_datasets
        )

        def __get_hyperscale_mount_point_by_id(
            self,
            hyperscale_mount_point_id,
            **kwargs
        ):
            """Get a Hyperscale Mount Points.  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.get_hyperscale_mount_point_by_id(hyperscale_mount_point_id, async_req=True)
            >>> result = thread.get()

            Args:
                hyperscale_mount_point_id (str): The ID of the Hyperscale Mount Point.

            Keyword Args:
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                HyperscaleMountPoint
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['hyperscale_mount_point_id'] = \
                hyperscale_mount_point_id
            return self.call_with_http_info(**kwargs)

        self.get_hyperscale_mount_point_by_id = _Endpoint(
            settings={
                'response_type': (HyperscaleMountPoint,),
                'auth': [
                    'ApiKeyAuth'
                ],
                'endpoint_path': '/hyperscale-mount-points/{hyperscaleMountPointId}',
                'operation_id': 'get_hyperscale_mount_point_by_id',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'hyperscale_mount_point_id',
                ],
                'required': [
                    'hyperscale_mount_point_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                    'hyperscale_mount_point_id',
                ]
            },
            root_map={
                'validations': {
                    ('hyperscale_mount_point_id',): {

                        'min_length': 1,
                    },
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'hyperscale_mount_point_id':
                        (str,),
                },
                'attribute_map': {
                    'hyperscale_mount_point_id': 'hyperscaleMountPointId',
                },
                'location_map': {
                    'hyperscale_mount_point_id': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client,
            callable=__get_hyperscale_mount_point_by_id
        )

        def __get_hyperscale_mount_points(
            self,
            **kwargs
        ):
            """Returns a list of Hyperscale Mount Points.  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.get_hyperscale_mount_points(async_req=True)
            >>> result = thread.get()


            Keyword Args:
                limit (int): Maximum number of objects to return per query. The value must be between 1 and 1000. Default is 100.. [optional] if omitted the server will use the default value of 100
                cursor (str): Cursor to fetch the next or previous page of results. The value of this property must be extracted from the 'prev_cursor' or 'next_cursor' property of a PaginatedResponseMetadata which is contained in the response of list and search API endpoints.. [optional]
                sort (str, none_type): The field to sort results by. A property name with a prepended '-' signifies descending order.. [optional]
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                ListHyperscaleMountPointsResponse
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            return self.call_with_http_info(**kwargs)

        self.get_hyperscale_mount_points = _Endpoint(
            settings={
                'response_type': (ListHyperscaleMountPointsResponse,),
                'auth': [
                    'ApiKeyAuth'
                ],
                'endpoint_path': '/hyperscale-mount-points',
                'operation_id': 'get_hyperscale_mount_points',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'limit',
                    'cursor',
                    'sort',
                ],
                'required': [],
                'nullable': [
                    'sort',
                ],
                'enum': [
                    'sort',
                ],
                'validation': [
                    'limit',
                    'cursor',
                ]
            },
            root_map={
                'validations': {
                    ('limit',): {

                        'inclusive_maximum': 1000,
                        'inclusive_minimum': 1,
                    },
                    ('cursor',): {
                        'max_length': 4096,
                        'min_length': 1,
                    },
                },
                'allowed_values': {
                    ('sort',): {
                        'None': None,
                        "ID": "id",
                        "-ID": "-id",
                        "NAME": "name",
                        "-NAME": "-name",
                        "HOSTNAME": "hostname",
                        "-HOSTNAME": "-hostname",
                        "MOUNT_TYPE": "mount_type",
                        "-MOUNT_TYPE": "-mount_type",
                        "OPTIONS": "options",
                        "-OPTIONS": "-options",
                        "MOUNT_PATH": "mount_path",
                        "-MOUNT_PATH": "-mount_path",
                        "STAGING_STORAGE_TYPE": "staging_storage_type",
                        "-STAGING_STORAGE_TYPE": "-staging_storage_type",
                        "AUTH_MECHANISM": "auth_mechanism",
                        "-AUTH_MECHANISM": "-auth_mechanism",
                        "AWS_BUCKET_NAME": "aws_bucket_name",
                        "-AWS_BUCKET_NAME": "-aws_bucket_name",
                        "AWS_BUCKET_REGION": "aws_bucket_region",
                        "-AWS_BUCKET_REGION": "-aws_bucket_region",
                        "AWS_BUCKET_PREFIX": "aws_bucket_prefix",
                        "-AWS_BUCKET_PREFIX": "-aws_bucket_prefix",
                        "AWS_BUCKET_DELIMITER": "aws_bucket_delimiter",
                        "-AWS_BUCKET_DELIMITER": "-aws_bucket_delimiter",
                        "BLOB_AUTH_TYPE": "blob_auth_type",
                        "-BLOB_AUTH_TYPE": "-blob_auth_type",
                        "BLOB_ACCOUNT_NAME": "blob_account_name",
                        "-BLOB_ACCOUNT_NAME": "-blob_account_name",
                        "BLOB_CONTAINER_NAME": "blob_container_name",
                        "-BLOB_CONTAINER_NAME": "-blob_container_name",
                        "BLOB_CONTAINER_PREFIX": "blob_container_prefix",
                        "-BLOB_CONTAINER_PREFIX": "-blob_container_prefix",
                        "BLOB_CONTAINER_DELIMITER": "blob_container_delimiter",
                        "-BLOB_CONTAINER_DELIMITER": "-blob_container_delimiter",
                        "HYPERSCALE_INSTANCE_ID": "hyperscale_instance_id",
                        "-HYPERSCALE_INSTANCE_ID": "-hyperscale_instance_id"
                    },
                },
                'openapi_types': {
                    'limit':
                        (int,),
                    'cursor':
                        (str,),
                    'sort':
                        (str, none_type,),
                },
                'attribute_map': {
                    'limit': 'limit',
                    'cursor': 'cursor',
                    'sort': 'sort',
                },
                'location_map': {
                    'limit': 'query',
                    'cursor': 'query',
                    'sort': 'query',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client,
            callable=__get_hyperscale_mount_points
        )

        def __search_hyperscale_connectors(
            self,
            **kwargs
        ):
            """Search for Hyperscale Connectors.  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.search_hyperscale_connectors(async_req=True)
            >>> result = thread.get()


            Keyword Args:
                limit (int): Maximum number of objects to return per query. The value must be between 1 and 1000. Default is 100.. [optional] if omitted the server will use the default value of 100
                cursor (str): Cursor to fetch the next or previous page of results. The value of this property must be extracted from the 'prev_cursor' or 'next_cursor' property of a PaginatedResponseMetadata which is contained in the response of list and search API endpoints.. [optional]
                sort (str, none_type): The field to sort results by. A property name with a prepended '-' signifies descending order.. [optional]
                search_body (SearchBody): A request body containing a filter expression. This enables searching for items matching arbitrarily complex conditions. The list of attributes which can be used in filter expressions is available in the x-filterable vendor extension.  # Filter Expression Overview **Note: All keywords are case-insensitive**  ## Comparison Operators | Operator | Description | Example | | --- | --- | --- | | CONTAINS | Substring or membership testing for string and list attributes respectively. | field3 CONTAINS 'foobar', field4 CONTAINS TRUE  | | IN | Tests if field is a member of a list literal. List can contain a maximum of 100 values | field2 IN ['Goku', 'Vegeta'] | | GE | Tests if a field is greater than or equal to a literal value | field1 GE 1.2e-2 | | GT | Tests if a field is greater than a literal value | field1 GT 1.2e-2 | | LE | Tests if a field is less than or equal to a literal value | field1 LE 9000 | | LT | Tests if a field is less than a literal value | field1 LT 9.02 | | NE | Tests if a field is not equal to a literal value | field1 NE 42 | | EQ | Tests if a field is equal to a literal value | field1 EQ 42 |  ## Search Operator The SEARCH operator filters for items which have any filterable attribute that contains the input string as a substring, comparison is done case-insensitively. This is not restricted to attributes with string values. Specifically `SEARCH '12'` would match an item with an attribute with an integer value of `123`.  ## Logical Operators Ordered by precedence. | Operator | Description | Example | | --- | --- | --- | | NOT | Logical NOT (Right associative) | NOT field1 LE 9000 | | AND | Logical AND (Left Associative) | field1 GT 9000 AND field2 EQ 'Goku' | | OR | Logical OR (Left Associative) | field1 GT 9000 OR field2 EQ 'Goku' |  ## Grouping Parenthesis `()` can be used to override operator precedence.  For example: NOT (field1 LT 1234 AND field2 CONTAINS 'foo')  ## Literal Values | Literal      | Description | Examples | | --- | --- | --- | | Nil | Represents the absence of a value | nil, Nil, nIl, NIL | | Boolean | true/false boolean | true, false, True, False, TRUE, FALSE | | Number | Signed integer and floating point numbers. Also supports scientific notation. | 0, 1, -1, 1.2, 0.35, 1.2e-2, -1.2e+2 | | String | Single or double quoted | \"foo\", \"bar\", \"foo bar\", 'foo', 'bar', 'foo bar' | | Datetime | Formatted according to [RFC3339](https://datatracker.ietf.org/doc/html/rfc3339) | 2018-04-27T18:39:26.397237+00:00 | | List | Comma-separated literals wrapped in square brackets | [0], [0, 1], ['foo', \"bar\"] |  ## Limitations - A maximum of 8 unique identifiers may be used inside a filter expression. . [optional]
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                SearchHyperscaleConnectorsResponse
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            return self.call_with_http_info(**kwargs)

        self.search_hyperscale_connectors = _Endpoint(
            settings={
                'response_type': (SearchHyperscaleConnectorsResponse,),
                'auth': [
                    'ApiKeyAuth'
                ],
                'endpoint_path': '/hyperscale-connectors/search',
                'operation_id': 'search_hyperscale_connectors',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'limit',
                    'cursor',
                    'sort',
                    'search_body',
                ],
                'required': [],
                'nullable': [
                    'sort',
                ],
                'enum': [
                    'sort',
                ],
                'validation': [
                    'limit',
                    'cursor',
                ]
            },
            root_map={
                'validations': {
                    ('limit',): {

                        'inclusive_maximum': 1000,
                        'inclusive_minimum': 1,
                    },
                    ('cursor',): {
                        'max_length': 4096,
                        'min_length': 1,
                    },
                },
                'allowed_values': {
                    ('sort',): {
                        'None': None,
                        "ID": "id",
                        "-ID": "-id",
                        "NAME": "name",
                        "-NAME": "-name",
                        "HYPERSCALE_INSTANCE_ID": "hyperscale_instance_id",
                        "-HYPERSCALE_INSTANCE_ID": "-hyperscale_instance_id",
                        "DATA_TYPE": "data_type",
                        "-DATA_TYPE": "-data_type",
                        "SOURCE_USERNAME": "source_username",
                        "-SOURCE_USERNAME": "-source_username",
                        "SOURCE_JDBC_URL": "source_jdbc_url",
                        "-SOURCE_JDBC_URL": "-source_jdbc_url",
                        "SOURCE_MONGO_URL": "source_mongo_url",
                        "-SOURCE_MONGO_URL": "-source_mongo_url",
                        "TARGET_USERNAME": "target_username",
                        "-TARGET_USERNAME": "-target_username",
                        "TARGET_JDBC_URL": "target_jdbc_url",
                        "-TARGET_JDBC_URL": "-target_jdbc_url",
                        "TARGET_MONGO_URL": "target_mongo_url",
                        "-TARGET_MONGO_URL": "-target_mongo_url"
                    },
                },
                'openapi_types': {
                    'limit':
                        (int,),
                    'cursor':
                        (str,),
                    'sort':
                        (str, none_type,),
                    'search_body':
                        (SearchBody,),
                },
                'attribute_map': {
                    'limit': 'limit',
                    'cursor': 'cursor',
                    'sort': 'sort',
                },
                'location_map': {
                    'limit': 'query',
                    'cursor': 'query',
                    'sort': 'query',
                    'search_body': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client,
            callable=__search_hyperscale_connectors
        )

        def __search_hyperscale_dataset_tables_or_files(
            self,
            hyperscale_dataset_id,
            **kwargs
        ):
            """Search the tables or files of a hyperscale dataset  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.search_hyperscale_dataset_tables_or_files(hyperscale_dataset_id, async_req=True)
            >>> result = thread.get()

            Args:
                hyperscale_dataset_id (str): The ID of the Hyperscale Dataset.

            Keyword Args:
                limit (int): Maximum number of objects to return per query. The value must be between 1 and 1000. Default is 100.. [optional] if omitted the server will use the default value of 100
                cursor (str): Cursor to fetch the next or previous page of results. The value of this property must be extracted from the 'prev_cursor' or 'next_cursor' property of a PaginatedResponseMetadata which is contained in the response of list and search API endpoints.. [optional]
                sort (str, none_type): The field to sort results by. A property name with a prepended '-' signifies descending order.. [optional]
                search_body (SearchBody): A request body containing a filter expression. This enables searching for items matching arbitrarily complex conditions. The list of attributes which can be used in filter expressions is available in the x-filterable vendor extension.  # Filter Expression Overview **Note: All keywords are case-insensitive**  ## Comparison Operators | Operator | Description | Example | | --- | --- | --- | | CONTAINS | Substring or membership testing for string and list attributes respectively. | field3 CONTAINS 'foobar', field4 CONTAINS TRUE  | | IN | Tests if field is a member of a list literal. List can contain a maximum of 100 values | field2 IN ['Goku', 'Vegeta'] | | GE | Tests if a field is greater than or equal to a literal value | field1 GE 1.2e-2 | | GT | Tests if a field is greater than a literal value | field1 GT 1.2e-2 | | LE | Tests if a field is less than or equal to a literal value | field1 LE 9000 | | LT | Tests if a field is less than a literal value | field1 LT 9.02 | | NE | Tests if a field is not equal to a literal value | field1 NE 42 | | EQ | Tests if a field is equal to a literal value | field1 EQ 42 |  ## Search Operator The SEARCH operator filters for items which have any filterable attribute that contains the input string as a substring, comparison is done case-insensitively. This is not restricted to attributes with string values. Specifically `SEARCH '12'` would match an item with an attribute with an integer value of `123`.  ## Logical Operators Ordered by precedence. | Operator | Description | Example | | --- | --- | --- | | NOT | Logical NOT (Right associative) | NOT field1 LE 9000 | | AND | Logical AND (Left Associative) | field1 GT 9000 AND field2 EQ 'Goku' | | OR | Logical OR (Left Associative) | field1 GT 9000 OR field2 EQ 'Goku' |  ## Grouping Parenthesis `()` can be used to override operator precedence.  For example: NOT (field1 LT 1234 AND field2 CONTAINS 'foo')  ## Literal Values | Literal      | Description | Examples | | --- | --- | --- | | Nil | Represents the absence of a value | nil, Nil, nIl, NIL | | Boolean | true/false boolean | true, false, True, False, TRUE, FALSE | | Number | Signed integer and floating point numbers. Also supports scientific notation. | 0, 1, -1, 1.2, 0.35, 1.2e-2, -1.2e+2 | | String | Single or double quoted | \"foo\", \"bar\", \"foo bar\", 'foo', 'bar', 'foo bar' | | Datetime | Formatted according to [RFC3339](https://datatracker.ietf.org/doc/html/rfc3339) | 2018-04-27T18:39:26.397237+00:00 | | List | Comma-separated literals wrapped in square brackets | [0], [0, 1], ['foo', \"bar\"] |  ## Limitations - A maximum of 8 unique identifiers may be used inside a filter expression. . [optional]
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                SearchHyperscaleDatasetTablesOrFilesResponse
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['hyperscale_dataset_id'] = \
                hyperscale_dataset_id
            return self.call_with_http_info(**kwargs)

        self.search_hyperscale_dataset_tables_or_files = _Endpoint(
            settings={
                'response_type': (SearchHyperscaleDatasetTablesOrFilesResponse,),
                'auth': [
                    'ApiKeyAuth'
                ],
                'endpoint_path': '/hyperscale-datasets/{hyperscaleDatasetId}/tables-or-files/search',
                'operation_id': 'search_hyperscale_dataset_tables_or_files',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'hyperscale_dataset_id',
                    'limit',
                    'cursor',
                    'sort',
                    'search_body',
                ],
                'required': [
                    'hyperscale_dataset_id',
                ],
                'nullable': [
                    'sort',
                ],
                'enum': [
                    'sort',
                ],
                'validation': [
                    'hyperscale_dataset_id',
                    'limit',
                    'cursor',
                ]
            },
            root_map={
                'validations': {
                    ('hyperscale_dataset_id',): {

                        'min_length': 1,
                    },
                    ('limit',): {

                        'inclusive_maximum': 1000,
                        'inclusive_minimum': 1,
                    },
                    ('cursor',): {
                        'max_length': 4096,
                        'min_length': 1,
                    },
                },
                'allowed_values': {
                    ('sort',): {
                        'None': None,
                        "ID": "id",
                        "-ID": "-id",
                        "SCHEMA_NAME": "schema_name",
                        "-SCHEMA_NAME": "-schema_name",
                        "TABLE_NAME": "table_name",
                        "-TABLE_NAME": "-table_name",
                        "DATABASE_NAME": "database_name",
                        "-DATABASE_NAME": "-database_name",
                        "COLLECTION_NAME": "collection_name",
                        "-COLLECTION_NAME": "-collection_name",
                        "FILTER_KEY": "filter_key",
                        "-FILTER_KEY": "-filter_key",
                        "COLUMN_ARRAY_ROWS": "column_array_rows",
                        "-COLUMN_ARRAY_ROWS": "-column_array_rows",
                        "UNLOAD_SPLIT": "unload_split",
                        "-UNLOAD_SPLIT": "-unload_split",
                        "STREAM_SIZE": "stream_size",
                        "-STREAM_SIZE": "-stream_size"
                    },
                },
                'openapi_types': {
                    'hyperscale_dataset_id':
                        (str,),
                    'limit':
                        (int,),
                    'cursor':
                        (str,),
                    'sort':
                        (str, none_type,),
                    'search_body':
                        (SearchBody,),
                },
                'attribute_map': {
                    'hyperscale_dataset_id': 'hyperscaleDatasetId',
                    'limit': 'limit',
                    'cursor': 'cursor',
                    'sort': 'sort',
                },
                'location_map': {
                    'hyperscale_dataset_id': 'path',
                    'limit': 'query',
                    'cursor': 'query',
                    'sort': 'query',
                    'search_body': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client,
            callable=__search_hyperscale_dataset_tables_or_files
        )

        def __search_hyperscale_datasets(
            self,
            **kwargs
        ):
            """Search for Hyperscale Datasets.  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.search_hyperscale_datasets(async_req=True)
            >>> result = thread.get()


            Keyword Args:
                limit (int): Maximum number of objects to return per query. The value must be between 1 and 1000. Default is 100.. [optional] if omitted the server will use the default value of 100
                cursor (str): Cursor to fetch the next or previous page of results. The value of this property must be extracted from the 'prev_cursor' or 'next_cursor' property of a PaginatedResponseMetadata which is contained in the response of list and search API endpoints.. [optional]
                sort (str, none_type): The field to sort results by. A property name with a prepended '-' signifies descending order.. [optional]
                search_body (SearchBody): A request body containing a filter expression. This enables searching for items matching arbitrarily complex conditions. The list of attributes which can be used in filter expressions is available in the x-filterable vendor extension.  # Filter Expression Overview **Note: All keywords are case-insensitive**  ## Comparison Operators | Operator | Description | Example | | --- | --- | --- | | CONTAINS | Substring or membership testing for string and list attributes respectively. | field3 CONTAINS 'foobar', field4 CONTAINS TRUE  | | IN | Tests if field is a member of a list literal. List can contain a maximum of 100 values | field2 IN ['Goku', 'Vegeta'] | | GE | Tests if a field is greater than or equal to a literal value | field1 GE 1.2e-2 | | GT | Tests if a field is greater than a literal value | field1 GT 1.2e-2 | | LE | Tests if a field is less than or equal to a literal value | field1 LE 9000 | | LT | Tests if a field is less than a literal value | field1 LT 9.02 | | NE | Tests if a field is not equal to a literal value | field1 NE 42 | | EQ | Tests if a field is equal to a literal value | field1 EQ 42 |  ## Search Operator The SEARCH operator filters for items which have any filterable attribute that contains the input string as a substring, comparison is done case-insensitively. This is not restricted to attributes with string values. Specifically `SEARCH '12'` would match an item with an attribute with an integer value of `123`.  ## Logical Operators Ordered by precedence. | Operator | Description | Example | | --- | --- | --- | | NOT | Logical NOT (Right associative) | NOT field1 LE 9000 | | AND | Logical AND (Left Associative) | field1 GT 9000 AND field2 EQ 'Goku' | | OR | Logical OR (Left Associative) | field1 GT 9000 OR field2 EQ 'Goku' |  ## Grouping Parenthesis `()` can be used to override operator precedence.  For example: NOT (field1 LT 1234 AND field2 CONTAINS 'foo')  ## Literal Values | Literal      | Description | Examples | | --- | --- | --- | | Nil | Represents the absence of a value | nil, Nil, nIl, NIL | | Boolean | true/false boolean | true, false, True, False, TRUE, FALSE | | Number | Signed integer and floating point numbers. Also supports scientific notation. | 0, 1, -1, 1.2, 0.35, 1.2e-2, -1.2e+2 | | String | Single or double quoted | \"foo\", \"bar\", \"foo bar\", 'foo', 'bar', 'foo bar' | | Datetime | Formatted according to [RFC3339](https://datatracker.ietf.org/doc/html/rfc3339) | 2018-04-27T18:39:26.397237+00:00 | | List | Comma-separated literals wrapped in square brackets | [0], [0, 1], ['foo', \"bar\"] |  ## Limitations - A maximum of 8 unique identifiers may be used inside a filter expression. . [optional]
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                SearchHyperscaleDatasetsResponse
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            return self.call_with_http_info(**kwargs)

        self.search_hyperscale_datasets = _Endpoint(
            settings={
                'response_type': (SearchHyperscaleDatasetsResponse,),
                'auth': [
                    'ApiKeyAuth'
                ],
                'endpoint_path': '/hyperscale-datasets/search',
                'operation_id': 'search_hyperscale_datasets',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'limit',
                    'cursor',
                    'sort',
                    'search_body',
                ],
                'required': [],
                'nullable': [
                    'sort',
                ],
                'enum': [
                    'sort',
                ],
                'validation': [
                    'limit',
                    'cursor',
                ]
            },
            root_map={
                'validations': {
                    ('limit',): {

                        'inclusive_maximum': 1000,
                        'inclusive_minimum': 1,
                    },
                    ('cursor',): {
                        'max_length': 4096,
                        'min_length': 1,
                    },
                },
                'allowed_values': {
                    ('sort',): {
                        'None': None,
                        "ID": "id",
                        "-ID": "-id",
                        "HYPERSCALE_INSTANCE_ID": "hyperscale_instance_id",
                        "-HYPERSCALE_INSTANCE_ID": "-hyperscale_instance_id",
                        "DATA_TYPE": "data_type",
                        "-DATA_TYPE": "-data_type",
                        "CONNECTOR_ID": "connector_id",
                        "-CONNECTOR_ID": "-connector_id",
                        "MOUNT_POINT_ID": "mount_point_id",
                        "-MOUNT_POINT_ID": "-mount_point_id"
                    },
                },
                'openapi_types': {
                    'limit':
                        (int,),
                    'cursor':
                        (str,),
                    'sort':
                        (str, none_type,),
                    'search_body':
                        (SearchBody,),
                },
                'attribute_map': {
                    'limit': 'limit',
                    'cursor': 'cursor',
                    'sort': 'sort',
                },
                'location_map': {
                    'limit': 'query',
                    'cursor': 'query',
                    'sort': 'query',
                    'search_body': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client,
            callable=__search_hyperscale_datasets
        )

        def __search_hyperscale_mount_points(
            self,
            **kwargs
        ):
            """Search for Hyperscale Mount Points.  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.search_hyperscale_mount_points(async_req=True)
            >>> result = thread.get()


            Keyword Args:
                limit (int): Maximum number of objects to return per query. The value must be between 1 and 1000. Default is 100.. [optional] if omitted the server will use the default value of 100
                cursor (str): Cursor to fetch the next or previous page of results. The value of this property must be extracted from the 'prev_cursor' or 'next_cursor' property of a PaginatedResponseMetadata which is contained in the response of list and search API endpoints.. [optional]
                sort (str, none_type): The field to sort results by. A property name with a prepended '-' signifies descending order.. [optional]
                search_body (SearchBody): A request body containing a filter expression. This enables searching for items matching arbitrarily complex conditions. The list of attributes which can be used in filter expressions is available in the x-filterable vendor extension.  # Filter Expression Overview **Note: All keywords are case-insensitive**  ## Comparison Operators | Operator | Description | Example | | --- | --- | --- | | CONTAINS | Substring or membership testing for string and list attributes respectively. | field3 CONTAINS 'foobar', field4 CONTAINS TRUE  | | IN | Tests if field is a member of a list literal. List can contain a maximum of 100 values | field2 IN ['Goku', 'Vegeta'] | | GE | Tests if a field is greater than or equal to a literal value | field1 GE 1.2e-2 | | GT | Tests if a field is greater than a literal value | field1 GT 1.2e-2 | | LE | Tests if a field is less than or equal to a literal value | field1 LE 9000 | | LT | Tests if a field is less than a literal value | field1 LT 9.02 | | NE | Tests if a field is not equal to a literal value | field1 NE 42 | | EQ | Tests if a field is equal to a literal value | field1 EQ 42 |  ## Search Operator The SEARCH operator filters for items which have any filterable attribute that contains the input string as a substring, comparison is done case-insensitively. This is not restricted to attributes with string values. Specifically `SEARCH '12'` would match an item with an attribute with an integer value of `123`.  ## Logical Operators Ordered by precedence. | Operator | Description | Example | | --- | --- | --- | | NOT | Logical NOT (Right associative) | NOT field1 LE 9000 | | AND | Logical AND (Left Associative) | field1 GT 9000 AND field2 EQ 'Goku' | | OR | Logical OR (Left Associative) | field1 GT 9000 OR field2 EQ 'Goku' |  ## Grouping Parenthesis `()` can be used to override operator precedence.  For example: NOT (field1 LT 1234 AND field2 CONTAINS 'foo')  ## Literal Values | Literal      | Description | Examples | | --- | --- | --- | | Nil | Represents the absence of a value | nil, Nil, nIl, NIL | | Boolean | true/false boolean | true, false, True, False, TRUE, FALSE | | Number | Signed integer and floating point numbers. Also supports scientific notation. | 0, 1, -1, 1.2, 0.35, 1.2e-2, -1.2e+2 | | String | Single or double quoted | \"foo\", \"bar\", \"foo bar\", 'foo', 'bar', 'foo bar' | | Datetime | Formatted according to [RFC3339](https://datatracker.ietf.org/doc/html/rfc3339) | 2018-04-27T18:39:26.397237+00:00 | | List | Comma-separated literals wrapped in square brackets | [0], [0, 1], ['foo', \"bar\"] |  ## Limitations - A maximum of 8 unique identifiers may be used inside a filter expression. . [optional]
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                SearchHyperscaleMountPointsResponse
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            return self.call_with_http_info(**kwargs)

        self.search_hyperscale_mount_points = _Endpoint(
            settings={
                'response_type': (SearchHyperscaleMountPointsResponse,),
                'auth': [
                    'ApiKeyAuth'
                ],
                'endpoint_path': '/hyperscale-mount-points/search',
                'operation_id': 'search_hyperscale_mount_points',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'limit',
                    'cursor',
                    'sort',
                    'search_body',
                ],
                'required': [],
                'nullable': [
                    'sort',
                ],
                'enum': [
                    'sort',
                ],
                'validation': [
                    'limit',
                    'cursor',
                ]
            },
            root_map={
                'validations': {
                    ('limit',): {

                        'inclusive_maximum': 1000,
                        'inclusive_minimum': 1,
                    },
                    ('cursor',): {
                        'max_length': 4096,
                        'min_length': 1,
                    },
                },
                'allowed_values': {
                    ('sort',): {
                        'None': None,
                        "ID": "id",
                        "-ID": "-id",
                        "NAME": "name",
                        "-NAME": "-name",
                        "HOSTNAME": "hostname",
                        "-HOSTNAME": "-hostname",
                        "MOUNT_TYPE": "mount_type",
                        "-MOUNT_TYPE": "-mount_type",
                        "OPTIONS": "options",
                        "-OPTIONS": "-options",
                        "MOUNT_PATH": "mount_path",
                        "-MOUNT_PATH": "-mount_path",
                        "STAGING_STORAGE_TYPE": "staging_storage_type",
                        "-STAGING_STORAGE_TYPE": "-staging_storage_type",
                        "AUTH_MECHANISM": "auth_mechanism",
                        "-AUTH_MECHANISM": "-auth_mechanism",
                        "AWS_BUCKET_NAME": "aws_bucket_name",
                        "-AWS_BUCKET_NAME": "-aws_bucket_name",
                        "AWS_BUCKET_REGION": "aws_bucket_region",
                        "-AWS_BUCKET_REGION": "-aws_bucket_region",
                        "AWS_BUCKET_PREFIX": "aws_bucket_prefix",
                        "-AWS_BUCKET_PREFIX": "-aws_bucket_prefix",
                        "AWS_BUCKET_DELIMITER": "aws_bucket_delimiter",
                        "-AWS_BUCKET_DELIMITER": "-aws_bucket_delimiter",
                        "BLOB_AUTH_TYPE": "blob_auth_type",
                        "-BLOB_AUTH_TYPE": "-blob_auth_type",
                        "BLOB_ACCOUNT_NAME": "blob_account_name",
                        "-BLOB_ACCOUNT_NAME": "-blob_account_name",
                        "BLOB_CONTAINER_NAME": "blob_container_name",
                        "-BLOB_CONTAINER_NAME": "-blob_container_name",
                        "BLOB_CONTAINER_PREFIX": "blob_container_prefix",
                        "-BLOB_CONTAINER_PREFIX": "-blob_container_prefix",
                        "BLOB_CONTAINER_DELIMITER": "blob_container_delimiter",
                        "-BLOB_CONTAINER_DELIMITER": "-blob_container_delimiter",
                        "HYPERSCALE_INSTANCE_ID": "hyperscale_instance_id",
                        "-HYPERSCALE_INSTANCE_ID": "-hyperscale_instance_id"
                    },
                },
                'openapi_types': {
                    'limit':
                        (int,),
                    'cursor':
                        (str,),
                    'sort':
                        (str, none_type,),
                    'search_body':
                        (SearchBody,),
                },
                'attribute_map': {
                    'limit': 'limit',
                    'cursor': 'cursor',
                    'sort': 'sort',
                },
                'location_map': {
                    'limit': 'query',
                    'cursor': 'query',
                    'sort': 'query',
                    'search_body': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client,
            callable=__search_hyperscale_mount_points
        )

        def __update_hyperscale_connector_by_id(
            self,
            hyperscale_connector_id,
            **kwargs
        ):
            """Update a Hyperscale Connector by ID.  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.update_hyperscale_connector_by_id(hyperscale_connector_id, async_req=True)
            >>> result = thread.get()

            Args:
                hyperscale_connector_id (str): The ID of the Hyperscale Connector.

            Keyword Args:
                hyperscale_connector_update_parameters (HyperscaleConnectorUpdateParameters): The new data to update a Hyperscale Connector.. [optional]
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                UpdateHyperscaleConnectorResponse
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['hyperscale_connector_id'] = \
                hyperscale_connector_id
            return self.call_with_http_info(**kwargs)

        self.update_hyperscale_connector_by_id = _Endpoint(
            settings={
                'response_type': (UpdateHyperscaleConnectorResponse,),
                'auth': [
                    'ApiKeyAuth'
                ],
                'endpoint_path': '/hyperscale-connectors/{hyperscaleConnectorId}',
                'operation_id': 'update_hyperscale_connector_by_id',
                'http_method': 'PATCH',
                'servers': None,
            },
            params_map={
                'all': [
                    'hyperscale_connector_id',
                    'hyperscale_connector_update_parameters',
                ],
                'required': [
                    'hyperscale_connector_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                    'hyperscale_connector_id',
                ]
            },
            root_map={
                'validations': {
                    ('hyperscale_connector_id',): {

                        'min_length': 1,
                    },
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'hyperscale_connector_id':
                        (str,),
                    'hyperscale_connector_update_parameters':
                        (HyperscaleConnectorUpdateParameters,),
                },
                'attribute_map': {
                    'hyperscale_connector_id': 'hyperscaleConnectorId',
                },
                'location_map': {
                    'hyperscale_connector_id': 'path',
                    'hyperscale_connector_update_parameters': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client,
            callable=__update_hyperscale_connector_by_id
        )

        def __update_hyperscale_dataset_by_id(
            self,
            hyperscale_dataset_id,
            **kwargs
        ):
            """Update a Hyperscale Dataset by ID.  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.update_hyperscale_dataset_by_id(hyperscale_dataset_id, async_req=True)
            >>> result = thread.get()

            Args:
                hyperscale_dataset_id (str): The ID of the Hyperscale Dataset.

            Keyword Args:
                hyperscale_dataset_update_parameters (HyperscaleDatasetUpdateParameters): The new data to update a Hyperscale Dataset.. [optional]
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                UpdateHyperscaleDatasetResponse
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['hyperscale_dataset_id'] = \
                hyperscale_dataset_id
            return self.call_with_http_info(**kwargs)

        self.update_hyperscale_dataset_by_id = _Endpoint(
            settings={
                'response_type': (UpdateHyperscaleDatasetResponse,),
                'auth': [
                    'ApiKeyAuth'
                ],
                'endpoint_path': '/hyperscale-datasets/{hyperscaleDatasetId}',
                'operation_id': 'update_hyperscale_dataset_by_id',
                'http_method': 'PATCH',
                'servers': None,
            },
            params_map={
                'all': [
                    'hyperscale_dataset_id',
                    'hyperscale_dataset_update_parameters',
                ],
                'required': [
                    'hyperscale_dataset_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                    'hyperscale_dataset_id',
                ]
            },
            root_map={
                'validations': {
                    ('hyperscale_dataset_id',): {

                        'min_length': 1,
                    },
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'hyperscale_dataset_id':
                        (str,),
                    'hyperscale_dataset_update_parameters':
                        (HyperscaleDatasetUpdateParameters,),
                },
                'attribute_map': {
                    'hyperscale_dataset_id': 'hyperscaleDatasetId',
                },
                'location_map': {
                    'hyperscale_dataset_id': 'path',
                    'hyperscale_dataset_update_parameters': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client,
            callable=__update_hyperscale_dataset_by_id
        )

        def __update_hyperscale_dataset_table_or_file_by_id(
            self,
            hyperscale_dataset_id,
            hyperscale_dataset_table_or_file_id,
            **kwargs
        ):
            """Update a Hyperscale Dataset table or file by ID.  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.update_hyperscale_dataset_table_or_file_by_id(hyperscale_dataset_id, hyperscale_dataset_table_or_file_id, async_req=True)
            >>> result = thread.get()

            Args:
                hyperscale_dataset_id (str): The ID of the Hyperscale Dataset.
                hyperscale_dataset_table_or_file_id (str): The ID of the Hyperscale Dataset table or file.

            Keyword Args:
                hyperscale_dataset_table_or_file_update_parameters (HyperscaleDatasetTableOrFileUpdateParameters): The new data to update a Hyperscale Dataset table or file.. [optional]
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                UpdateHyperscaleDatasetTableOrFileResponse
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['hyperscale_dataset_id'] = \
                hyperscale_dataset_id
            kwargs['hyperscale_dataset_table_or_file_id'] = \
                hyperscale_dataset_table_or_file_id
            return self.call_with_http_info(**kwargs)

        self.update_hyperscale_dataset_table_or_file_by_id = _Endpoint(
            settings={
                'response_type': (UpdateHyperscaleDatasetTableOrFileResponse,),
                'auth': [
                    'ApiKeyAuth'
                ],
                'endpoint_path': '/hyperscale-datasets/{hyperscaleDatasetId}/tables-or-files/{hyperscaleDatasetTableOrFileId}',
                'operation_id': 'update_hyperscale_dataset_table_or_file_by_id',
                'http_method': 'PATCH',
                'servers': None,
            },
            params_map={
                'all': [
                    'hyperscale_dataset_id',
                    'hyperscale_dataset_table_or_file_id',
                    'hyperscale_dataset_table_or_file_update_parameters',
                ],
                'required': [
                    'hyperscale_dataset_id',
                    'hyperscale_dataset_table_or_file_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                    'hyperscale_dataset_id',
                    'hyperscale_dataset_table_or_file_id',
                ]
            },
            root_map={
                'validations': {
                    ('hyperscale_dataset_id',): {

                        'min_length': 1,
                    },
                    ('hyperscale_dataset_table_or_file_id',): {

                        'min_length': 1,
                    },
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'hyperscale_dataset_id':
                        (str,),
                    'hyperscale_dataset_table_or_file_id':
                        (str,),
                    'hyperscale_dataset_table_or_file_update_parameters':
                        (HyperscaleDatasetTableOrFileUpdateParameters,),
                },
                'attribute_map': {
                    'hyperscale_dataset_id': 'hyperscaleDatasetId',
                    'hyperscale_dataset_table_or_file_id': 'hyperscaleDatasetTableOrFileId',
                },
                'location_map': {
                    'hyperscale_dataset_id': 'path',
                    'hyperscale_dataset_table_or_file_id': 'path',
                    'hyperscale_dataset_table_or_file_update_parameters': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client,
            callable=__update_hyperscale_dataset_table_or_file_by_id
        )

        def __update_hyperscale_mount_point_by_id(
            self,
            hyperscale_mount_point_id,
            **kwargs
        ):
            """Update a Hyperscale Mount Point by ID.  # noqa: E501

            This method makes a synchronous HTTP request by default. To make an
            asynchronous HTTP request, please pass async_req=True

            >>> thread = api.update_hyperscale_mount_point_by_id(hyperscale_mount_point_id, async_req=True)
            >>> result = thread.get()

            Args:
                hyperscale_mount_point_id (str): The ID of the Hyperscale Mount Point.

            Keyword Args:
                hyperscale_mount_point_update_parameters (HyperscaleMountPointUpdateParameters): The new data to update a Hyperscale Mount Point.. [optional]
                _return_http_data_only (bool): response data without head status
                    code and headers. Default is True.
                _preload_content (bool): if False, the urllib3.HTTPResponse object
                    will be returned without reading/decoding response data.
                    Default is True.
                _request_timeout (int/float/tuple): timeout setting for this request. If
                    one number provided, it will be total request timeout. It can also
                    be a pair (tuple) of (connection, read) timeouts.
                    Default is None.
                _check_input_type (bool): specifies if type checking
                    should be done one the data sent to the server.
                    Default is True.
                _check_return_type (bool): specifies if type checking
                    should be done one the data received from the server.
                    Default is True.
                _host_index (int/None): specifies the index of the server
                    that we want to use.
                    Default is read from the configuration.
                async_req (bool): execute request asynchronously

            Returns:
                UpdateHyperscaleMountPointResponse
                    If the method is called asynchronously, returns the request
                    thread.
            """
            kwargs['async_req'] = kwargs.get(
                'async_req', False
            )
            kwargs['_return_http_data_only'] = kwargs.get(
                '_return_http_data_only', True
            )
            kwargs['_preload_content'] = kwargs.get(
                '_preload_content', True
            )
            kwargs['_request_timeout'] = kwargs.get(
                '_request_timeout', None
            )
            kwargs['_check_input_type'] = kwargs.get(
                '_check_input_type', True
            )
            kwargs['_check_return_type'] = kwargs.get(
                '_check_return_type', True
            )
            kwargs['_host_index'] = kwargs.get('_host_index')
            kwargs['hyperscale_mount_point_id'] = \
                hyperscale_mount_point_id
            return self.call_with_http_info(**kwargs)

        self.update_hyperscale_mount_point_by_id = _Endpoint(
            settings={
                'response_type': (UpdateHyperscaleMountPointResponse,),
                'auth': [
                    'ApiKeyAuth'
                ],
                'endpoint_path': '/hyperscale-mount-points/{hyperscaleMountPointId}',
                'operation_id': 'update_hyperscale_mount_point_by_id',
                'http_method': 'PATCH',
                'servers': None,
            },
            params_map={
                'all': [
                    'hyperscale_mount_point_id',
                    'hyperscale_mount_point_update_parameters',
                ],
                'required': [
                    'hyperscale_mount_point_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                    'hyperscale_mount_point_id',
                ]
            },
            root_map={
                'validations': {
                    ('hyperscale_mount_point_id',): {

                        'min_length': 1,
                    },
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'hyperscale_mount_point_id':
                        (str,),
                    'hyperscale_mount_point_update_parameters':
                        (HyperscaleMountPointUpdateParameters,),
                },
                'attribute_map': {
                    'hyperscale_mount_point_id': 'hyperscaleMountPointId',
                },
                'location_map': {
                    'hyperscale_mount_point_id': 'path',
                    'hyperscale_mount_point_update_parameters': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client,
            callable=__update_hyperscale_mount_point_by_id
        )



"""
    Delphix DCT API

    Delphix DCT API  # noqa: E501

    The version of the OpenAPI document: 3.27.0
    Contact: support@delphix.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import delphix.api.gateway
from delphix.api.gateway.api.cloud_accounts_api import CloudAccountsApi  # noqa: E501


class TestCloudAccountsApi(unittest.TestCase):
    """CloudAccountsApi unit test stubs"""

    def setUp(self):
        self.api = CloudAccountsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_cloud_account(self):
        """Test case for create_cloud_account

        Create a new Cloud Account  # noqa: E501
        """
        pass

    def test_create_cloud_account_tags(self):
        """Test case for create_cloud_account_tags

        Create tags for a Cloud Account.  # noqa: E501
        """
        pass

    def test_delete_cloud_account(self):
        """Test case for delete_cloud_account

        """
        pass

    def test_delete_cloud_account_tags(self):
        """Test case for delete_cloud_account_tags

        Delete tags for a Cloud Account.  # noqa: E501
        """
        pass

    def test_get_cloud_account_metadata(self):
        """Test case for get_cloud_account_metadata

        Cloud Account metadata  # noqa: E501
        """
        pass

    def test_get_cloud_account_tags(self):
        """Test case for get_cloud_account_tags

        Get tags for a Cloud Account.  # noqa: E501
        """
        pass

    def test_get_cloud_accounts(self):
        """Test case for get_cloud_accounts

        List all Cloud Accounts.  # noqa: E501
        """
        pass

    def test_search_cloud_accounts(self):
        """Test case for search_cloud_accounts

        Search for Cloud Accounts.  # noqa: E501
        """
        pass

    def test_update_cloud_account(self):
        """Test case for update_cloud_account

        Update an existing Cloud Account  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Delphix DCT API

    Delphix DCT API  # noqa: E501

    The version of the OpenAPI document: 3.27.0
    Contact: support@delphix.com
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401
import sys  # noqa: F401

from delphix.api.gateway.model_utils import (  # noqa: F401
    ApiTypeError,
    ModelComposed,
    ModelNormal,
    ModelSimple,
    cached_property,
    change_keys_js_to_python,
    convert_js_args_to_python_args,
    date,
    datetime,
    file_type,
    none_type,
    validate_get_composed_info,
)
from ..model_utils import OpenApiModel
from delphix.api.gateway.exceptions import ApiAttributeError


def lazy_import():
    from delphix.api.gateway.model.generate_data_attribute import GenerateDataAttribute
    globals()['GenerateDataAttribute'] = GenerateDataAttribute


class GenerateDataRequest(ModelNormal):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.

    Attributes:
      allowed_values (dict): The key is the tuple path to the attribute
          and the for var_name this is (var_name,). The value is a dict
          with a capitalized key describing the allowed value and an allowed
          value. These dicts store the allowed enum values.
      attribute_map (dict): The key is attribute name
          and the value is json key in definition.
      discriminator_value_class_map (dict): A dict to go from the discriminator
          variable value to the discriminator class name.
      validations (dict): The key is the tuple path to the attribute
          and the for var_name this is (var_name,). The value is a dict
          that stores validations for max_length, min_length, max_items,
          min_items, exclusive_maximum, inclusive_maximum, exclusive_minimum,
          inclusive_minimum, and regex.
      additional_properties_type (tuple): A tuple of classes accepted
          as additional properties values.
    """

    allowed_values = {
    }

    validations = {
        ('attributes',): {
            'min_items': 0,
        },
        ('max_value_length',): {
            'inclusive_maximum': 4000,
            'inclusive_minimum': 1,
        },
        ('requested_count',): {
            'inclusive_minimum': 1,
        },
    }

    @cached_property
    def additional_properties_type():
        """
        This must be a method because a model may have properties that are
        of type self, this must run after the class is loaded
        """
        lazy_import()
        return (bool, date, datetime, dict, float, int, list, str, none_type,)  # noqa: E501

    _nullable = False

    @cached_property
    def openapi_types():
        """
        This must be a method because a model may have properties that are
        of type self, this must run after the class is loaded

        Returns
            openapi_types (dict): The key is attribute name
                and the value is attribute type.
        """
        lazy_import()
        return {
            'name': (str,),  # noqa: E501
            'data_type': (str,),  # noqa: E501
            'multiline_values': (bool,),  # noqa: E501
            'description': (str,),  # noqa: E501
            'attributes': ([GenerateDataAttribute],),  # noqa: E501
            'max_value_length': (int,),  # noqa: E501
            'requested_count': (int,),  # noqa: E501
            'filter_characters': (str,),  # noqa: E501
            'allow_duplicates': (bool,),  # noqa: E501
            'trim_values': (bool,),  # noqa: E501
            'retention_time': (int,),  # noqa: E501
            'error_tolerance': (int,),  # noqa: E501
            'priority': (int,),  # noqa: E501
        }

    @cached_property
    def discriminator():
        return None


    attribute_map = {
        'name': 'name',  # noqa: E501
        'data_type': 'data_type',  # noqa: E501
        'multiline_values': 'multiline_values',  # noqa: E501
        'description': 'description',  # noqa: E501
        'attributes': 'attributes',  # noqa: E501
        'max_value_length': 'max_value_length',  # noqa: E501
        'requested_count': 'requested_count',  # noqa: E501
        'filter_characters': 'filter_characters',  # noqa: E501
        'allow_duplicates': 'allow_duplicates',  # noqa: E501
        'trim_values': 'trim_values',  # noqa: E501
        'retention_time': 'retention_time',  # noqa: E501
        'error_tolerance': 'error_tolerance',  # noqa: E501
        'priority': 'priority',  # noqa: E501
    }

    read_only_vars = {
    }

    _composed_schemas = {}

    @classmethod
    @convert_js_args_to_python_args
    def _from_openapi_data(cls, name, data_type, multiline_values, *args, **kwargs):  # noqa: E501
        """GenerateDataRequest - a model defined in OpenAPI

        Args:
            name (str): A name for this data generation request. This name will be used for the generated file, if requested.
            data_type (str): The type of data to generate
            multiline_values (bool): Whether to allow generation of multiline values. Values generated with this setting true cannot be exported to secure lookup files. When this value is false, multiline values are rejected.

        Keyword Args:
            _check_type (bool): if True, values for parameters in openapi_types
                                will be type checked and a TypeError will be
                                raised if the wrong type is input.
                                Defaults to True
            _path_to_item (tuple/list): This is a list of keys or values to
                                drill down to the model in received_data
                                when deserializing a response
            _spec_property_naming (bool): True if the variable names in the input data
                                are serialized names, as specified in the OpenAPI document.
                                False if the variable names in the input data
                                are pythonic names, e.g. snake case (default)
            _configuration (Configuration): the instance to use when
                                deserializing a file_type parameter.
                                If passed, type conversion is attempted
                                If omitted no type conversion is done.
            _visited_composed_classes (tuple): This stores a tuple of
                                classes that we have traveled through so that
                                if we see that class again we will not use its
                                discriminator again.
                                When traveling through a discriminator, the
                                composed schema that is
                                is traveled through is added to this set.
                                For example if Animal has a discriminator
                                petType and we pass in "Dog", and the class Dog
                                allOf includes Animal, we move through Animal
                                once using the discriminator, and pick Dog.
                                Then in Dog, we will make an instance of the
                                Animal class but this time we won't travel
                                through its discriminator because we passed in
                                _visited_composed_classes = (Animal,)
            description (str): An optional description for this data generation request. [optional]  # noqa: E501
            attributes ([GenerateDataAttribute]): Attributes to use when generating some values. For each attribute, generation will iterate over each value, so each attribute value will apply to a subset of the generated values. An empty \"\" in the values list will cause generation skip this attribute for some generated values.. [optional]  # noqa: E501
            max_value_length (int): The maximum length in characters for each generated value. Generated values which are too long are discarded. The default value depends on whether multiline_values is enabled.. [optional]  # noqa: E501
            requested_count (int): The number of values to generate. [optional] if omitted the server will use the default value of 10  # noqa: E501
            filter_characters (str): A Java regular expression that matches each character to filter from the generated values.. [optional] if omitted the server will use the default value of ""  # noqa: E501
            allow_duplicates (bool): Whether to allow duplicate values in the generated value list. [optional] if omitted the server will use the default value of False  # noqa: E501
            trim_values (bool): Whether to trim leading and trailing whitespace from generated values.. [optional] if omitted the server will use the default value of True  # noqa: E501
            retention_time (int): The length of time, in seconds, that generated values should be made available in the API. Values will always be available while the generated request is running. No value means data will be retained indefinitely.. [optional]  # noqa: E501
            error_tolerance (int): The quantity of unusable, duplicate or failed LLM prompts allowed before the generate operation will fail. This value is expressed as a percentage multiple of total expected number of prompts need to complete the generate operation. Given the high likelihood of duplicate values, this value should not be decreased unless it is critical to time/resource bound the generate operation.. [optional] if omitted the server will use the default value of 300  # noqa: E501
            priority (int): The request priority, where higher values mean higher priority. This will typically be 0 for bulk operations and 1 for sample generation.. [optional] if omitted the server will use the default value of 0  # noqa: E501
        """

        _check_type = kwargs.pop('_check_type', True)
        _spec_property_naming = kwargs.pop('_spec_property_naming', False)
        _path_to_item = kwargs.pop('_path_to_item', ())
        _configuration = kwargs.pop('_configuration', None)
        _visited_composed_classes = kwargs.pop('_visited_composed_classes', ())

        self = super(OpenApiModel, cls).__new__(cls)

        if args:
            raise ApiTypeError(
                "Invalid positional arguments=%s passed to %s. Remove those invalid positional arguments." % (
                    args,
                    self.__class__.__name__,
                ),
                path_to_item=_path_to_item,
                valid_classes=(self.__class__,),
            )

        self._data_store = {}
        self._check_type = _check_type
        self._spec_property_naming = _spec_property_naming
        self._path_to_item = _path_to_item
        self._configuration = _configuration
        self._visited_composed_classes = _visited_composed_classes + (self.__class__,)

        self.name = name
        self.data_type = data_type
        self.multiline_values = multiline_values
        for var_name, var_value in kwargs.items():
            if var_name not in self.attribute_map and \
                        self._configuration is not None and \
                        self._configuration.discard_unknown_keys and \
                        self.additional_properties_type is None:
                # discard variable.
                continue
            setattr(self, var_name, var_value)
        return self

    required_properties = set([
        '_data_store',
        '_check_type',
        '_spec_property_naming',
        '_path_to_item',
        '_configuration',
        '_visited_composed_classes',
    ])

    @convert_js_args_to_python_args
    def __init__(self, name, data_type, multiline_values, *args, **kwargs):  # noqa: E501
        """GenerateDataRequest - a model defined in OpenAPI

        Args:
            name (str): A name for this data generation request. This name will be used for the generated file, if requested.
            data_type (str): The type of data to generate
            multiline_values (bool): Whether to allow generation of multiline values. Values generated with this setting true cannot be exported to secure lookup files. When this value is false, multiline values are rejected.

        Keyword Args:
            _check_type (bool): if True, values for parameters in openapi_types
                                will be type checked and a TypeError will be
                                raised if the wrong type is input.
                                Defaults to True
            _path_to_item (tuple/list): This is a list of keys or values to
                                drill down to the model in received_data
                                when deserializing a response
            _spec_property_naming (bool): True if the variable names in the input data
                                are serialized names, as specified in the OpenAPI document.
                                False if the variable names in the input data
                                are pythonic names, e.g. snake case (default)
            _configuration (Configuration): the instance to use when
                                deserializing a file_type parameter.
                                If passed, type conversion is attempted
                                If omitted no type conversion is done.
            _visited_composed_classes (tuple): This stores a tuple of
                                classes that we have traveled through so that
                                if we see that class again we will not use its
                                discriminator again.
                                When traveling through a discriminator, the
                                composed schema that is
                                is traveled through is added to this set.
                                For example if Animal has a discriminator
                                petType and we pass in "Dog", and the class Dog
                                allOf includes Animal, we move through Animal
                                once using the discriminator, and pick Dog.
                                Then in Dog, we will make an instance of the
                                Animal class but this time we won't travel
                                through its discriminator because we passed in
                                _visited_composed_classes = (Animal,)
            description (str): An optional description for this data generation request. [optional]  # noqa: E501
            attributes ([GenerateDataAttribute]): Attributes to use when generating some values. For each attribute, generation will iterate over each value, so each attribute value will apply to a subset of the generated values. An empty \"\" in the values list will cause generation skip this attribute for some generated values.. [optional]  # noqa: E501
            max_value_length (int): The maximum length in characters for each generated value. Generated values which are too long are discarded. The default value depends on whether multiline_values is enabled.. [optional]  # noqa: E501
            requested_count (int): The number of values to generate. [optional] if omitted the server will use the default value of 10  # noqa: E501
            filter_characters (str): A Java regular expression that matches each character to filter from the generated values.. [optional] if omitted the server will use the default value of ""  # noqa: E501
            allow_duplicates (bool): Whether to allow duplicate values in the generated value list. [optional] if omitted the server will use the default value of False  # noqa: E501
            trim_values (bool): Whether to trim leading and trailing whitespace from generated values.. [optional] if omitted the server will use the default value of True  # noqa: E501
            retention_time (int): The length of time, in seconds, that generated values should be made available in the API. Values will always be available while the generated request is running. No value means data will be retained indefinitely.. [optional]  # noqa: E501
            error_tolerance (int): The quantity of unusable, duplicate or failed LLM prompts allowed before the generate operation will fail. This value is expressed as a percentage multiple of total expected number of prompts need to complete the generate operation. Given the high likelihood of duplicate values, this value should not be decreased unless it is critical to time/resource bound the generate operation.. [optional] if omitted the server will use the default value of 300  # noqa: E501
            priority (int): The request priority, where higher values mean higher priority. This will typically be 0 for bulk operations and 1 for sample generation.. [optional] if omitted the server will use the default value of 0  # noqa: E501
        """

        _check_type = kwargs.pop('_check_type', True)
        _spec_property_naming = kwargs.pop('_spec_property_naming', False)
        _path_to_item = kwargs.pop('_path_to_item', ())
        _configuration = kwargs.pop('_configuration', None)
        _visited_composed_classes = kwargs.pop('_visited_composed_classes', ())

        if args:
            raise ApiTypeError(
                "Invalid positional arguments=%s passed to %s. Remove those invalid positional arguments." % (
                    args,
                    self.__class__.__name__,
                ),
                path_to_item=_path_to_item,
                valid_classes=(self.__class__,),
            )

        self._data_store = {}
        self._check_type = _check_type
        self._spec_property_naming = _spec_property_naming
        self._path_to_item = _path_to_item
        self._configuration = _configuration
        self._visited_composed_classes = _visited_composed_classes + (self.__class__,)

        self.name = name
        self.data_type = data_type
        self.multiline_values = multiline_values
        for var_name, var_value in kwargs.items():
            if var_name not in self.attribute_map and \
                        self._configuration is not None and \
                        self._configuration.discard_unknown_keys and \
                        self.additional_properties_type is None:
                # discard variable.
                continue
            setattr(self, var_name, var_value)
            if var_name in self.read_only_vars:
                raise ApiAttributeError(f"`{var_name}` is a read-only attribute. Use `from_openapi_data` to instantiate "
                                     f"class with read only attributes.")



"""
    Delphix DCT API

    Delphix DCT API  # noqa: E501

    The version of the OpenAPI document: 3.27.0
    Contact: support@delphix.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import delphix.api.gateway
from delphix.api.gateway.api.held_space_api import HeldSpaceApi  # noqa: E501


class TestHeldSpaceApi(unittest.TestCase):
    """HeldSpaceApi unit test stubs"""

    def setUp(self):
        self.api = HeldSpaceApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_delete_heldspace_by_id(self):
        """Test case for delete_heldspace_by_id

        Delete a HeldSpace.  # noqa: E501
        """
        pass

    def test_get_heldspace_deletion_dependencies(self):
        """Test case for get_heldspace_deletion_dependencies

        Get heldspace deletion dependencies.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Delphix DCT API

    Delphix DCT API  # noqa: E501

    The version of the OpenAPI document: 3.27.0
    Contact: support@delphix.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import delphix.api.gateway
from delphix.api.gateway.api.cdb_d_sources_api import CDBDSourcesApi  # noqa: E501


class TestCDBDSourcesApi(unittest.TestCase):
    """CDBDSourcesApi unit test stubs"""

    def setUp(self):
        self.api = CDBDSourcesApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_attach_cdb_dsource(self):
        """Test case for attach_cdb_dsource

        Attaches an Oracle CDB to an Oracle database.  # noqa: E501
        """
        pass

    def test_create_cdb_dsource_tags(self):
        """Test case for create_cdb_dsource_tags

        Create tags for a CDB DSource.  # noqa: E501
        """
        pass

    def test_delete_cdb_dsource(self):
        """Test case for delete_cdb_dsource

        Delete a CDB dSource.  # noqa: E501
        """
        pass

    def test_delete_cdb_dsource_tags(self):
        """Test case for delete_cdb_dsource_tags

        Delete tags for a CDB DSource.  # noqa: E501
        """
        pass

    def test_detach_cdb_dsource(self):
        """Test case for detach_cdb_dsource

        Detaches an Oracle CDB from an Oracle database.  # noqa: E501
        """
        pass

    def test_disable_cdb_dsource(self):
        """Test case for disable_cdb_dsource

        Disable a CDB dSource.  # noqa: E501
        """
        pass

    def test_enable_cdb_dsource(self):
        """Test case for enable_cdb_dsource

        Enable a CDB dSource.  # noqa: E501
        """
        pass

    def test_get_cdb_dsource_by_id(self):
        """Test case for get_cdb_dsource_by_id

        Get a CDB dSource by ID (Oracle only).  # noqa: E501
        """
        pass

    def test_get_cdb_dsources(self):
        """Test case for get_cdb_dsources

        List all CDB dSources (Oracle only).  # noqa: E501
        """
        pass

    def test_get_tags_cdb_dsource(self):
        """Test case for get_tags_cdb_dsource

        Get tags for a CDB DSource.  # noqa: E501
        """
        pass

    def test_search_cdb_dsources(self):
        """Test case for search_cdb_dsources

        Search for CDB dSources (Oracle only).  # noqa: E501
        """
        pass

    def test_update_cdb_dsource(self):
        """Test case for update_cdb_dsource

        Update a CDB DSource.  # noqa: E501
        """
        pass

    def test_upgrade_cdb_dsource(self):
        """Test case for upgrade_cdb_dsource

        Upgrade Oracle CDB dSource  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Delphix DCT API

    Delphix DCT API  # noqa: E501

    The version of the OpenAPI document: 3.27.0
    Contact: support@delphix.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import delphix.api.gateway
from delphix.api.gateway.api.file_mapping_api import FileMappingApi  # noqa: E501


class TestFileMappingApi(unittest.TestCase):
    """FileMappingApi unit test stubs"""

    def setUp(self):
        self.api = FileMappingApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_file_mapping_by_bookmark(self):
        """Test case for get_file_mapping_by_bookmark

        Validate file mapping using bookmark  # noqa: E501
        """
        pass

    def test_get_file_mapping_by_location(self):
        """Test case for get_file_mapping_by_location

        Validate file mapping using location  # noqa: E501
        """
        pass

    def test_get_file_mapping_by_snapshot(self):
        """Test case for get_file_mapping_by_snapshot

        Validate file mapping using snapshots  # noqa: E501
        """
        pass

    def test_get_file_mapping_by_timestamp(self):
        """Test case for get_file_mapping_by_timestamp

        Validate file mapping using timestamp  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Delphix DCT API

    Delphix DCT API  # noqa: E501

    The version of the OpenAPI document: 3.27.0
    Contact: support@delphix.com
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import delphix.api.gateway
from delphix.api.gateway.model.engine_historical_storage_summary import EngineHistoricalStorageSummary
globals()['EngineHistoricalStorageSummary'] = EngineHistoricalStorageSummary
from delphix.api.gateway.model.historical_storage_summary import HistoricalStorageSummary


class TestHistoricalStorageSummary(unittest.TestCase):
    """HistoricalStorageSummary unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testHistoricalStorageSummary(self):
        """Test HistoricalStorageSummary"""
        # FIXME: construct object with mandatory attributes with example values
        # model = HistoricalStorageSummary()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
